/*
 *  cvLoadRGBJPEGBuffer.h
 *
 * Reads an RGB JPEG data buffer in memory and allocates/initialized a
 * OpenCV IplImage struct.
 *
 * To use: 
 * const unsigned char *jpeg_buf = ... // buffer containing jpeg data.
 * long jpeg_buf_size = ... // size of buffer
 * IplImage *img;
 * img = cvLoadRGBJPEGBuffer (jpeg_buf, jpeg_buf_size);
 * ... // Do stuff
 * cvReleaseImage (&img);
 *  
 * Copyright (C) 2009 Jeffrey Nelson
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (www.gnu.org/licenses)
 */

#ifndef JPEG_MEMORY_SRC_H
#define JPEG_MEMORY_SRC_H

#include <opencv/highgui.h>
#include <opencv/cv.h>

/*
 * Returns an allocated/initialized IplImage from an in-memory jpeg buffer, 
 * or null on (some) error conditions.
 */
IplImage *cvLoadRGBJPEGBuffer (const unsigned char *buf, long size);


#endif
